@@ -19,15 +19,15 @@
 import logging
 import os
 import sys
-
-from liminal.runners.airflow.config.standalone_variable_backend import get_variable
+from time import sleep
 
 from kubernetes import client, config
 from kubernetes.client import V1PersistentVolume, V1PersistentVolumeClaim
 
+# noinspection PyBroadException
 try:
     config.load_kube_config()
-except:
+except Exception:
     msg = "Kubernetes is not running\n"
     sys.stdout.write(f"INFO: {msg}")
 
@@ -51,9 +51,8 @@ def create_local_volumes(liminal_config, base_dir):
             create_local_volume(volume_config)
 
 
-def create_local_volume(conf) -> None:
+def create_local_volume(conf, namespace='default') -> None:
     name = conf['volume']
-    namespace = get_variable('kubernetes_namespace', default_val='default')
 
     _LOG.info(f'Requested volume {name}')
 
@@ -62,8 +61,12 @@ def create_local_volume(conf) -> None:
             field_selector=f'metadata.name={name}'
         ).to_dict()['items']
 
-        if not len(matching_volumes) > 0:
+        while len(matching_volumes) == 0:
             _create_local_volume(conf, name)
+            sleep(5)
+            matching_volumes = _kubernetes.list_persistent_volume(
+                field_selector=f'metadata.name={name}'
+            ).to_dict()['items']
 
         pvc_name = conf.get('claim_name', f'{name}-pvc')
 
@@ -71,35 +74,53 @@ def create_local_volume(conf) -> None:
             field_selector=f'metadata.name={pvc_name}'
         ).to_dict()['items']
 
-        if not len(matching_claims) > 0:
+        while len(matching_claims) == 0:
             _create_persistent_volume_claim(pvc_name, name, namespace)
+            sleep(5)
+            matching_claims = _kubernetes.list_persistent_volume_claim_for_all_namespaces(
+                field_selector=f'metadata.name={pvc_name}'
+            ).to_dict()['items']
 
         _LOCAL_VOLUMES.add(name)
 
 
 def delete_local_volume(name, namespace='default'):
-    matching_volumes = _kubernetes.list_persistent_volume(
-        field_selector=f'metadata.name={name}'
-    ).to_dict()['items']
-
-    if len(matching_volumes) > 0:
-        _LOG.info(f'Deleting persistent volume {name}')
-        _kubernetes.delete_persistent_volume(name)
-
     pvc_name = f'{name}-pvc'
 
-    matching_claims = _kubernetes.list_persistent_volume_claim_for_all_namespaces(
-        field_selector=f'metadata.name={pvc_name}'
-    ).to_dict()['items']
+    matching_claims = _list_persistent_volume_claims(pvc_name)
 
     if len(matching_claims) > 0:
         _LOG.info(f'Deleting persistent volume claim {pvc_name}')
         _kubernetes.delete_namespaced_persistent_volume_claim(pvc_name, namespace)
 
+    while len(matching_claims) > 0:
+        matching_claims = _list_persistent_volume_claims(pvc_name)
+
+    matching_volumes = _list_persistent_volumes(name)
+
+    if len(matching_volumes) > 0:
+        _LOG.info(f'Deleting persistent volume {name}')
+        _kubernetes.delete_persistent_volume(name)
+
+    while len(matching_volumes) > 0:
+        matching_volumes = _list_persistent_volumes(name)
+
     if name in _LOCAL_VOLUMES:
         _LOCAL_VOLUMES.remove(name)
 
 
+def _list_persistent_volume_claims(name):
+    return _kubernetes.list_persistent_volume_claim_for_all_namespaces(
+        field_selector=f'metadata.name={name}'
+    ).to_dict()['items']
+
+
+def _list_persistent_volumes(name):
+    return _kubernetes.list_persistent_volume(
+        field_selector=f'metadata.name={name}'
+    ).to_dict()['items']
+
+
 def _create_persistent_volume_claim(pvc_name, volume_name, namespace):
     _LOG.info(f'Creating persistent volume claim {pvc_name} with volume {volume_name}')
     spec = {
