@@ -15,9 +15,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 import liminal.runners.airflow.dag as liminal
-import logging
+from airflow import DAG
 import traceback
 
 pipelines = liminal.register_dags()
@@ -25,7 +24,5 @@ pipelines = liminal.register_dags()
 for pipeline, dag in pipelines:
     try:
         globals()[pipeline] = dag
-        logging.info(f'registered DAG {dag.dag_id}: {dag.tasks}')
     except Exception:
-        logging.error(f'Failed to register DAGs for {pipeline}')
         traceback.print_exc()
